##
##  overmind.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 2.5.1
%define       V_snap 20240327

#   package information
Name:         overmind
Summary:      Process Manager
URL:          https://github.com/DarthSim/overmind
Vendor:       Sergey Alexandrovich
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Terminal
License:      MIT
Version:      %{V_base}.%{V_snap}
Release:      20240327

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/overmind/overmind-%{V_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Overmind is a process manager for Procfile-based applications and
    tmux(1). With Overmind, you can easily run several processes from
    your Procfile in a single terminal. Procfile is a simple format to
    specify types of processes your application provides (such as web
    application server, background queue process, front-end builder)
    and commands to run those processes. It can significantly simplify
    process management for developers and is used by popular hosting
    platforms, such as Heroku and Deis.

%track
    prog overmind = {
        version   = %{V_base}
        url       = https://github.com/DarthSim/overmind/releases
        regex     = v(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n overmind

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/DarthSim/overmind
    go build -v -ldflags "-X main.version=%{version}" -a -o overmind .

%install
    #   install program
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    %{l_shtool} install -c -s -m 755 \
        src/github.com/DarthSim/overmind/overmind \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

